package Setup;

our $VERSION = '1.0.6'; # VERSION

1;
# ABSTRACT: Specification for setup module

__END__

=pod

=encoding UTF-8

=head1 NAME

Setup - Specification for setup module

=head1 VERSION

This document describes version 1.0.6 of Setup (from Perl distribution Setup), released on 2021-08-02.

=head1 CONTRIBUTOR

=for stopwords Steven Haryanto

Steven Haryanto <sharyanto@cpan.org>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Setup>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Setup>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Setup>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2015, 2012 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
